AFBooleanField class

Inheritance

Constructors

AFBooleanField({required String id, required String name, required List<Validator<bool?>> validators, bool value = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique identifier for the field which will be used to retrieve its data.
finalinherited
name → String
The name that will be displayed to the user.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validators → List<Validator<Object?>>
A list of validators that will be used to verify the user's input.
finalinherited
value ↔ bool?
The current value of the field.
covariantgetter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parser(covariant bool unparsedValue) → bool?
override
toString() → String
A string representation of this object.
inherited
validate(bool? value) → String?
This method returns null if the field is valid. Otherwhise it will return the error's string specified in the validator (see Validator).
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited