EmailValidator class

Checks whether an email string is valid.

Inheritance

Constructors

EmailValidator(String error)
const

Properties

error → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

innerValidate(String? value) → bool
Returns true or false depending on the validation process. This method is then used by the ValidatorWithStaticError.validate method to return a static error if the result is false.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String? value) → String?
This method should return null if the field is valid, a string corresponding to the error otherwise.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited