FieldContext class

Constructors

FieldContext({required Field field, required bool forceErrorDisplay, required dynamic completeAction()?, FieldContext? previous})

Properties

completeAction → dynamic Function()?
final
errorText → String?
no setter
field → Field
final
focusStream → Stream<void>
no setter
forceErrorDisplay ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLast → bool
no setter
next ↔ FieldContext?
latefinal
previous → FieldContext?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(dynamic value) → void
sendRequestFocusEvent() → void
toString() → String
A string representation of this object.
inherited
updateWith({bool? forceErrorDisplay}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited