MinimumStringLengthValidator class

Checks whether a given string possess a minimum length.

Inheritance

Constructors

MinimumStringLengthValidator(int minStringLength, String error(String? value))
const

Properties

error → String Function(String? value)
final
hashCode → int
The hash code for this object.
no setterinherited
minStringLength → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String? value) → String?
This method should return null if the field is valid, a string corresponding to the error otherwise.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited