TemplateForm class abstract

An abstract class that makes it easy to create form with a strong validation system.

Use the toMap() method to retrieve all the fields values.

See Field and Validator for more information.

Implementers

Constructors

TemplateForm()

Properties

fields → List<Field>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String id) → T?
getFirstError() → String?
isComplete() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String id, dynamic value) → dynamic
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited