URLValidator class

Inheritance

Constructors

URLValidator(String error)
const

Properties

error → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

innerValidate(String? value) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String? value) → String?
This method should return null if the field is valid, a string corresponding to the error otherwhise.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited