Validator<T extends Object?> class abstract

The Validator class is used by the Field class to validate its input.

Implementers

Constructors

Validator()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(T value) → String?
This method should return null if the field is valid, a string corresponding to the error otherwhise.

Operators

operator ==(Object other) → bool
The equality operator.
inherited