ValidatorWithStaticError<T extends Object?> class abstract

As its name suggests, this class makes it easier to create a validator which returns a static error message (that does not change based on the data).

Inheritance
Implementers

Constructors

ValidatorWithStaticError(String error)
const

Properties

error → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

innerValidate(T? value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(T? value) → String?
This method should return null if the field is valid, a string corresponding to the error otherwhise.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited