AFTextField<T extends Object> class

The default Field extended class used to represent a form's text field.

Inheritance
Implementers

Constructors

AFTextField({required String id, required String name, required List<Validator<T>> validators, required AFTextFieldType type, T? value})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique identifier for the field which will be used to retrieve its data.
finalinherited
name → String
The name that will be displayed to the user.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AFTextFieldType
Depending on the value of this field, the widget's related instance will act differently. (For instance, if you choose the password option it will display a hide/display icon).
final
validators → List<Validator<Object?>>
A list of validators that will be used to verify the user's input.
finalinherited
value ↔ T?
The current value of the field.
covariantgetter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parser(covariant T? unparsedValue) → T?
override
toString() → String
A string representation of this object.
inherited
validate(T? value) → String?
This method returns null if the field is valid. Otherwhise it will return the error's string specified in the validator (see Validator).
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited